@@ -26,10 +26,10 @@ class PhpDocumentationWidget : public QStackedWidget
 
 public:
     explicit PhpDocumentationWidget(KDevelop::DocumentationFindWidget* find, const QUrl &url,
-                                    PhpDocsPlugin* provider, QWidget* parent = 0);
+                                    PhpDocsPlugin* provider, QWidget* parent = nullptr);
     ~PhpDocumentationWidget();
 
-private slots:
+private Q_SLOTS:
     /// used to inject some custom CSS to alter the remote php.net site
     void documentLoaded();
     void linkClicked(const QUrl& url);
