@@ -44,7 +44,7 @@ void CPPHeaderCodeAccessorMethod::updateContent()
     CPPCodeClassField * cppfield = dynamic_cast<CPPCodeClassField*>(parentField);
 
     // Check for dynamic casting failure!
-    if (cppfield == 0)
+    if (cppfield == nullptr)
     {
         logError0("cppfield: invalid dynamic cast");
         return;
@@ -54,7 +54,7 @@ void CPPHeaderCodeAccessorMethod::updateContent()
     CPPCodeGenerationPolicy * policy = dynamic_cast<CPPCodeGenerationPolicy*>(pe);
 
     // Check for dynamic casting failure!
-    if (policy == 0)
+    if (policy == nullptr)
     {
         logError0("policy: invalid dynamic cast");
         return;
@@ -75,12 +75,12 @@ void CPPHeaderCodeAccessorMethod::updateContent()
             text = policy->getVectorMethodRemove(variableName, itemClassName);
             break;
         case CodeAccessorMethod::SET:
-            text = variableName + QLatin1String(" = value;");
+            text = variableName + QStringLiteral(" = value;");
             break;
         case CodeAccessorMethod::LIST:
         case CodeAccessorMethod::GET:
         default:
-            text = QLatin1String("return ") + variableName + QLatin1Char(';');
+            text = QStringLiteral("return ") + variableName + QLatin1Char(';');
             break;
         }
     }
@@ -108,41 +108,41 @@ void CPPHeaderCodeAccessorMethod::updateMethodDeclaration()
     if(objectType.isEmpty())
         objectType = fieldName;
 
-    QString methodReturnType = QLatin1String("void");
-    QString methodName; // QLatin1String("get") + cppdoc->capitalizeFirstLetter(fieldName);
-    QString methodParams = QChar(QLatin1Char(' ')); // QLatin1String("get") + cppdoc->capitalizeFirstLetter(fieldName);
+    QString methodReturnType = QStringLiteral("void");
+    QString methodName; // QStringLiteral("get") + cppdoc->capitalizeFirstLetter(fieldName);
+    QString methodParams = QChar(QLatin1Char(' ')); // QStringLiteral("get") + cppdoc->capitalizeFirstLetter(fieldName);
     QString headerText;
     QString endLine = UMLApp::app()->commonPolicy()->getNewLineEndingChars();
 
     switch(getType()) {
     case CodeAccessorMethod::ADD:
-        methodName = QLatin1String("add_") + fieldType;
-        methodReturnType = QLatin1String("void");
-        methodParams = objectType + QLatin1String(" value ");
-        headerText = QLatin1String("Add a ") + fieldName + QLatin1String(" object to the ") + fieldName + QLatin1String("List") + endLine + getParentObject()->doc() + endLine + tag + QLatin1String("return void");
+        methodName = QStringLiteral("add_") + fieldType;
+        methodReturnType = QStringLiteral("void");
+        methodParams = objectType + QStringLiteral(" value ");
+        headerText = QStringLiteral("Add a ") + fieldName + QStringLiteral(" object to the ") + fieldName + QStringLiteral("List") + endLine + getParentObject()->doc() + endLine + tag + QStringLiteral("return void");
         break;
     case CodeAccessorMethod::REMOVE:
-        methodName = QLatin1String("remove_") + fieldType;
-        methodParams = objectType + QLatin1String(" value ");
-        methodReturnType = QLatin1String("void");
-        headerText = QLatin1String("Remove a ") + fieldName + QLatin1String(" object from the ") + fieldName + QLatin1String("List") + endLine + getParentObject()->doc() + endLine + tag + QLatin1String("return void");
+        methodName = QStringLiteral("remove_") + fieldType;
+        methodParams = objectType + QStringLiteral(" value ");
+        methodReturnType = QStringLiteral("void");
+        headerText = QStringLiteral("Remove a ") + fieldName + QStringLiteral(" object from the ") + fieldName + QStringLiteral("List") + endLine + getParentObject()->doc() + endLine + tag + QStringLiteral("return void");
         break;
     case CodeAccessorMethod::LIST:
-        methodName = QLatin1String("get_") + fieldType + QLatin1String("_list");
+        methodName = QStringLiteral("get_") + fieldType + QStringLiteral("_list");
         methodReturnType = vectorClassName;
-        headerText = QLatin1String("Get the ") + fieldName + QLatin1String("List") + endLine + getParentObject()->doc() + endLine + tag + QLatin1String("return ") + vectorClassName + QLatin1String("with list of objects");
+        headerText = QStringLiteral("Get the ") + fieldName + QStringLiteral("List") + endLine + getParentObject()->doc() + endLine + tag + QStringLiteral("return ") + vectorClassName + QStringLiteral("with list of objects");
         break;
     case CodeAccessorMethod::SET:
-        methodName = QLatin1String("set_") + fieldName;
-        methodParams = fieldType + QLatin1String(" value ");
-        methodReturnType = QLatin1String("void");
-        headerText = QLatin1String("Set the value of ") + fieldName + endLine + getParentObject()->doc() + endLine + tag + QLatin1String("param value the value of ") + fieldName;
+        methodName = QStringLiteral("set_") + fieldName;
+        methodParams = fieldType + QStringLiteral(" value ");
+        methodReturnType = QStringLiteral("void");
+        headerText = QStringLiteral("Set the value of ") + fieldName + endLine + getParentObject()->doc() + endLine + tag + QStringLiteral("param value the value of ") + fieldName;
         break;
     case CodeAccessorMethod::GET:
     default:
-        methodName = QLatin1String("get_") + fieldName;
+        methodName = QStringLiteral("get_") + fieldName;
         methodReturnType = fieldType;
-        headerText = QLatin1String("Get the value of ") + fieldName + endLine + getParentObject()->doc() + endLine + tag + QLatin1String("return the value of ") + fieldName;
+        headerText = QStringLiteral("Get the value of ") + fieldName + endLine + getParentObject()->doc() + endLine + tag + QStringLiteral("return the value of ") + fieldName;
         break;
     }
 
@@ -153,12 +153,12 @@ void CPPHeaderCodeAccessorMethod::updateMethodDeclaration()
     setComment(header);
 
     // set start/end method text
-    QString startText = methodReturnType + QLatin1Char(' ') + methodName + QLatin1String(" (") + methodParams  + QLatin1Char(')');
+    QString startText = methodReturnType + QLatin1Char(' ') + methodName + QStringLiteral(" (") + methodParams  + QLatin1Char(')');
     if (isInlineMethod)
-        startText += QLatin1String(" {");
+        startText += QStringLiteral(" {");
     else
         startText += QLatin1Char(';');
-    QString endText = (isInlineMethod ? QLatin1String("}") : QString());
+    QString endText = (isInlineMethod ? QStringLiteral("}") : QString());
 
     setStartMethodText(startText);
     setEndMethodText(endText);
