@@ -14,7 +14,7 @@
 #include "uml.h"
 #include "umldoc.h"
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 static const char *reserved_words[] = {
@@ -93,7 +93,7 @@ static const char *reserved_words[] = {
     "void",
     "volatile",
     "while",
-    0
+    nullptr
 };
 
 CSharpWriter::CSharpWriter()
@@ -161,7 +161,7 @@ QStringList CSharpWriter::defaultDatatypes() const
 void CSharpWriter::writeClass(UMLClassifier *c)
 {
     if (!c) {
-        logWarn0("CSharpWriter::writeClass: Cannot write class of NULL concept");
+        logWarn0("CSharpWriter::writeClass: Cannot write class of NULL classifier");
         return;
     }
 
@@ -169,13 +169,13 @@ void CSharpWriter::writeClass(UMLClassifier *c)
     //find an appropriate name for our file
     QString fileName = findFileName(c, QStringLiteral(".cs"));
     if (fileName.isEmpty()) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
     QFile filecs;
     if (!openFile(filecs, fileName)) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
     QTextStream cs(&filecs);
@@ -188,8 +188,8 @@ void CSharpWriter::writeClass(UMLClassifier *c)
     QString str;
     str = getHeadingFile(QStringLiteral(".cs"));
     if (!str.isEmpty()) {
-        str.replace(QRegExp(QStringLiteral("%filename%")), fileName);
-        str.replace(QRegExp(QStringLiteral("%filepath%")), filecs.fileName());
+        str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName);
+        str.replace(QRegularExpression(QStringLiteral("%filepath%")), filecs.fileName());
         cs << str << m_endl;
     }
 
@@ -206,7 +206,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
 
     UMLPackage *container = c->umlPackage();
     if (container == logicalView)
-        container = 0;
+        container = nullptr;
 
     UMLPackageList includes;
     findObjectsRelated(c, includes);
@@ -214,7 +214,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
     //m_seenIncludes.append(logicalView);
     if (includes.count()) {
 
-        foreach (UMLPackage* p, includes) {
+        for(UMLPackage* p : includes) {
             UMLClassifier *cl = p->asUMLClassifier();
             if (cl)
                 p = cl->umlPackage();
@@ -264,7 +264,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
         // write baseclass, ignore interfaces, write error on multiple inheritance
         if (superclasses.count() > 0) {
             int supers = 0;
-            foreach (UMLClassifier* obj, superclasses) {
+            for(UMLClassifier* obj : superclasses) {
                 if (!obj->isInterface()) {
                     if (supers > 0) {
                         cs << " // AND ";
@@ -281,7 +281,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
         UMLAssociationList realizations = c->getRealizations();
 
         if (!realizations.isEmpty()) {
-            foreach (UMLAssociation* a, realizations) {
+            for(UMLAssociation* a : realizations) {
                 UMLClassifier *real = (UMLClassifier*)a->getObject(Uml::RoleType::B);
                 if(real != c) {
                     // write list of realizations
@@ -325,8 +325,8 @@ void CSharpWriter::writeClass(UMLClassifier *c)
 
     //close files and notfiy we are done
     filecs.close();
-    emit codeGenerated(c, true);
-    emit showGeneratedFile(filecs.fileName());
+    Q_EMIT codeGenerated(c, true);
+    Q_EMIT showGeneratedFile(filecs.fileName());
 }
 
 ////////////////////////////////////////////////////////////////////////////////////
@@ -334,7 +334,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
 
 /**
  * Write all operations for a given class.
- * @param c the concept we are generating code for
+ * @param c the classifier we are generating code for
  * @param cs output stream
  */
 void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
@@ -347,7 +347,7 @@ void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
 
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList opl(c->getOpList());
-    foreach (UMLOperation* op,  opl) {
+    for(UMLOperation* op :  opl) {
         switch (op->visibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
@@ -411,11 +411,11 @@ void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTex
     // oplist for implemented abstract operations
     UMLOperationList opabstract;
 
-    foreach (UMLClassifier* obj, *superclasses) {
+    for(UMLClassifier* obj : *superclasses) {
         if (!obj->isInterface() && obj->hasAbstractOps()) {
             // collect abstract ops
             UMLOperationList opl(obj->getOpList());
-            foreach (UMLOperation* op, opl) {
+            for(UMLOperation* op : opl) {
                 if (op->isAbstract()) {
                     opabstract.append(op);
                 }
@@ -484,13 +484,13 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
                                  bool isOverride /* = false */,
                                  bool generateErrorStub /* = false */)
 {
-    foreach (UMLOperation* op, opList) {
+    for(UMLOperation* op : opList) {
         UMLAttributeList atl = op->getParmList();
 
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->doc().isEmpty();
 
-        foreach (UMLAttribute* at, atl) {
+        for(UMLAttribute* at : atl) {
             writeDoc |= !at->doc().isEmpty();
         }
 
@@ -502,14 +502,14 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
             cs << m_container_indent << m_indentation << "/// </summary>" << m_endl;
 
             //write parameter documentation
-            foreach (UMLAttribute* at, atl) {
+            for(UMLAttribute* at : atl) {
                 if (forceDoc() || !at->doc().isEmpty()) {
                     cs << m_container_indent << m_indentation << "/// <param name=\"" << cleanName(at->name()) << "\">";
                     //removing newlines from parameter doc
                     QString doc(formatDoc(at->doc(), QString()));
                     doc.replace(QLatin1Char('\n'), QLatin1Char(' '));
                     doc.remove(QLatin1Char('\r'));
-                    doc.remove(QRegExp(QStringLiteral(" $")));
+                    doc.remove(QRegularExpression(QStringLiteral(" $")));
                     cs << doc;
                     cs << "</param>" << m_endl;
                 }
@@ -561,7 +561,7 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
 
             // no initial values in C#
             //<< (!(at->getInitialValue().isEmpty()) ?
-            //    (QString(" = ")+at->getInitialValue()) :
+            //    (QStringLiteral(" = ")+at->getInitialValue()) :
             //    QString())
             cs << ((j < i-1) ? QStringLiteral(", ") : QString());
         }
@@ -602,7 +602,7 @@ void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs)
     //sort attributes by scope and see if they have a default value
     UMLAttributeList atl = c->getAttributeList();
 
-    foreach (UMLAttribute* at, atl) {
+    for(UMLAttribute* at : atl) {
         if (!at->getInitialValue().isEmpty())
             atdefval.append(at);
         switch (at->visibility()) {
@@ -650,7 +650,7 @@ void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs)
  */
 void CSharpWriter::writeAttributes(UMLAttributeList &atList, QTextStream &cs)
 {
-    foreach (UMLAttribute* at, atList) {
+    for(UMLAttribute* at : atList) {
 
         bool asProperty = true;
         if (at->visibility() == Uml::Visibility::Private) {
@@ -672,12 +672,12 @@ void CSharpWriter::writeAttributes(UMLAttributeList &atList, QTextStream &cs)
  */
 void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UMLClassifier *c, QTextStream &cs)
 {
-    foreach (UMLAssociation *a,  associated) {
+    for(UMLAssociation *a : associated) {
         if (c != a->getObject(Uml::RoleType::A))  // we need to be at the A side
             continue;
 
         UMLObject *o = a->getObject(Uml::RoleType::B);
-        if (o == 0) {
+        if (o == nullptr) {
             logError0("composition role B object is NULL");
             continue;
         }
