@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <brian.thomas@gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -20,7 +20,7 @@ DefaultCodeGenPolicyPage::DefaultCodeGenPolicyPage(QWidget *parent, const char *
         :CodeGenerationPolicyPage(parent, name, policy)
 {
     m_textLabel = new QLabel(this);
-    m_textLabel->setObjectName(QLatin1String("textLabel"));
+    m_textLabel->setObjectName(QStringLiteral("textLabel"));
     m_textLabel->setText(i18n("<p align=\"center\">No Options Available.</p>"));
 }
 
