@@ -23,7 +23,7 @@
 #include <KLocalizedString>
 
 // qt includes
-#include <QRegExp>
+#include <QRegularExpression>
 
 DEBUG_REGISTER(UMLOperation)
 
@@ -104,7 +104,7 @@ void UMLOperation::setType(UMLObject* type)
  */
 void UMLOperation::moveParmLeft(UMLAttribute * a)
 {
-    if (a == 0) {
+    if (a == nullptr) {
         logDebug0("UMLOperation::moveParmLeft called on NULL attribute");
         return;
     }
@@ -128,7 +128,7 @@ void UMLOperation::moveParmLeft(UMLAttribute * a)
  */
 void UMLOperation::moveParmRight(UMLAttribute * a)
 {
-    if (a == 0) {
+    if (a == nullptr) {
         logDebug0("UMLOperation::moveParmRight called on NULL attribute");
         return;
     }
@@ -156,7 +156,7 @@ void UMLOperation::moveParmRight(UMLAttribute * a)
  */
 void UMLOperation::removeParm(UMLAttribute * a, bool emitModifiedSignal /* =true */)
 {
-    if (a == 0) {
+    if (a == nullptr) {
         logDebug0("UMLOperation::removeParm called on NULL attribute");
         return;
     }
@@ -166,7 +166,7 @@ void UMLOperation::removeParm(UMLAttribute * a, bool emitModifiedSignal /* =true
         logDebug1("UMLOperation::removeParm: Error removing parm %1", a->name());
 
     if (emitModifiedSignal)
-        emit modified();
+        Q_EMIT modified();
 }
 
 /**
@@ -187,12 +187,11 @@ UMLAttributeList UMLOperation::getParmList() const
  */
 UMLAttribute* UMLOperation::findParm(const QString &name) const
 {
-    UMLAttribute * obj=0;
-    foreach (obj, m_args) {
+    for(UMLAttribute *obj: m_args) {
         if (obj->name() == name)
             return obj;
     }
-    return 0;
+    return (UMLAttribute*)nullptr;
 }
 
 /**
@@ -228,7 +227,7 @@ QString UMLOperation::toString(Uml::SignatureType::Enum sig, bool withStereotype
     if (last) {
         s.append(QStringLiteral("("));
         int i = 0;
-        foreach (UMLAttribute *param, m_args) {
+        for(UMLAttribute *param : m_args) {
             i++;
             s.append(param->toString(Uml::SignatureType::SigNoVis, withStereotype));
             if (i < last)
@@ -354,7 +353,7 @@ bool UMLOperation::resolveRef()
 {
     bool overallSuccess = UMLObject::resolveRef();
     // See remark on iteration style in UMLClassifier::resolveRef()
-    foreach (UMLAttribute* pAtt, m_args) {
+    for(UMLAttribute* pAtt : m_args) {
         if (! pAtt->resolveRef())
             overallSuccess = false;
     }
@@ -402,7 +401,7 @@ bool UMLOperation::isDestructorOperation() const
     // with "~" followed by the name of the parent classifier.
     if (! opName.startsWith(QLatin1Char('~')))
         return false;
-    opName.remove(QRegExp(QStringLiteral("^~\\s*")));
+    opName.remove(QRegularExpression(QStringLiteral("^~\\s*")));
     return (cName == opName);
 }
 
@@ -541,7 +540,7 @@ void UMLOperation::saveToXMI(QXmlStreamWriter& writer)
         writer.writeAttribute(QStringLiteral("isVirtual"), QStringLiteral("true"));
     if (m_bInline)
         writer.writeAttribute(QStringLiteral("isInline"), QStringLiteral("true"));
-    if (m_pSecondary == 0 && m_args.isEmpty()) {
+    if (m_pSecondary == nullptr && m_args.isEmpty()) {
         writer.writeEndElement();  // UML:Operation
         return;
     }
@@ -571,7 +570,7 @@ void UMLOperation::saveToXMI(QXmlStreamWriter& writer)
     }
 
     //save each attribute here, type different
-    foreach(UMLAttribute* pAtt, m_args) {
+    for(UMLAttribute* pAtt : m_args) {
         pAtt->UMLObject::save1(writer, QStringLiteral("Parameter"), QStringLiteral("ownedParameter"));
         UMLClassifier *attrType = pAtt->getType();
         if (attrType) {
@@ -685,7 +684,7 @@ bool UMLOperation::load1(QDomElement & element)
                     }
                 }
                 // Use deferred xmi.id resolution.
-                m_pSecondary = 0;
+                m_pSecondary = nullptr;
             } else {
                 UMLAttribute * pAtt = new UMLAttribute(this);
                 if(!pAtt->loadFromXMI(attElement)) {
