@@ -60,7 +60,7 @@ ObjectWidget::ObjectWidget(UMLScene * scene, UMLObject *o)
         m_pLine = new SeqLineWidget( m_scene, this );
         m_pLine->setStartPoint(x() + width() / 2, y() + height());
     } else {
-        m_pLine = 0;
+        m_pLine = nullptr;
     }
 }
 
@@ -172,7 +172,7 @@ void ObjectWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Properties:
         showPropertiesDialog();
         updateGeometry();
-        moveEvent(0);
+        moveEvent(nullptr);
         update();
         break;
 
@@ -198,8 +198,8 @@ QSizeF ObjectWidget::minimumSize() const
     int width, height;
     const QFontMetrics &fm = getFontMetrics(FT_UNDERLINE);
     const int fontHeight  = fm.lineSpacing();
-    const QString t = m_instanceName + QLatin1String(" : ") + name();
-    const int textWidth = fm.width(t);
+    const QString t = m_instanceName + QStringLiteral(" : ") + name();
+    const int textWidth = fm.horizontalAdvance(t);
     if (m_drawAsActor) {
         width = textWidth > A_WIDTH?textWidth:A_WIDTH;
         height = A_HEIGHT + fontHeight + A_MARGIN;
@@ -241,13 +241,13 @@ bool ObjectWidget::drawAsActor() const
 /**
  * Activate the object after serializing it from a QDataStream
  */
-bool ObjectWidget::activate(IDChangeLog* ChangeLog /*= 0*/)
+bool ObjectWidget::activate(IDChangeLog *ChangeLog /*= nullptr*/)
 {
     if (! UMLWidget::activate(ChangeLog))
         return false;
     if (m_showDestruction && m_pLine)
         m_pLine->setupDestructionBox();
-    moveEvent(0);
+    moveEvent(nullptr);
     return true;
 }
 
@@ -260,7 +260,7 @@ bool ObjectWidget::activate(IDChangeLog* ChangeLog /*= 0*/)
 void ObjectWidget::setX(qreal x)
 {
     UMLWidget::setX(x);
-    moveEvent(0);
+    moveEvent(nullptr);
 }
 
 /**
@@ -273,7 +273,7 @@ void ObjectWidget::setY(qreal y)
 {
     UMLWidget::setY(y);
     if (!UMLApp::app()->document()->loading())
-        moveEvent(0);
+        moveEvent(nullptr);
 }
 
 /**
@@ -291,7 +291,7 @@ qreal ObjectWidget::centerX()
 void ObjectWidget::moveEvent(QGraphicsSceneMouseEvent *event)
 {
     Q_UNUSED(event)
-    emit sigWidgetMoved(m_nLocalID);
+    Q_EMIT sigWidgetMoved(m_nLocalID);
     if (m_pLine) {
         m_pLine->setStartPoint(x() + width() / 2, y() + height());
     }
@@ -320,7 +320,7 @@ void ObjectWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* me)
     if (m_inResizeArea) {
         DEBUG() << "resizing...";
         resize(me);
-        moveEvent(0);
+        moveEvent(nullptr);
         return;
     }
 
@@ -370,7 +370,7 @@ void ObjectWidget::cleanup()
     if(m_pLine) {
         m_pLine->cleanup();
         delete m_pLine;
-        m_pLine = 0;
+        m_pLine = nullptr;
     }
 }
 
@@ -410,7 +410,7 @@ void ObjectWidget::paintObject(QPainter *painter)
     const int w = width();
     const int h = height();
 
-    const QString t = m_instanceName + QLatin1String(" : ") + name();
+    const QString t = m_instanceName + QStringLiteral(" : ") + name();
     int multiInstOfst = 0;
     if (m_multipleInstance) {
         painter->drawRect(10, 10, w - 10, h - 10);
@@ -454,7 +454,7 @@ void ObjectWidget::paintActor(QPainter *painter)
                middleX + A_WIDTH / 2, thirdH + thirdH / 2);//arms
     //draw text
     painter->setPen(textColor());
-    QString t = m_instanceName + QLatin1String(" : ") + name();
+    QString t = m_instanceName + QStringLiteral(" : ") + name();
     painter->drawText(A_MARGIN, textStartY,
                w - A_MARGIN * 2, fontHeight, Qt::AlignCenter, t);
 }
@@ -587,7 +587,7 @@ void ObjectWidget::slotMessageMoved()
 {
     if (m_pLine) {
         int lowestMessage = 0;
-        foreach (MessageWidget* message, m_messages) {
+        for(MessageWidget* message : m_messages) {
             int messageHeight = message->y() + message->height();
             if (lowestMessage < messageHeight) {
                 lowestMessage = messageHeight;
@@ -606,7 +606,7 @@ void ObjectWidget::slotMessageMoved()
  */
 bool ObjectWidget::messageOverlap(qreal y, MessageWidget* messageWidget)
 {
-    foreach (MessageWidget* message, m_messages) {
+    for(MessageWidget* message : m_messages) {
         if (message == messageWidget) {
             continue;
         }
@@ -672,11 +672,11 @@ void ObjectWidget::resizeWidget(qreal newW, qreal newH)
  */
 void ObjectWidget::saveToXMI(QXmlStreamWriter& writer)
 {
-    writer.writeStartElement(QLatin1String("objectwidget"));
+    writer.writeStartElement(QStringLiteral("objectwidget"));
     UMLWidget::saveToXMI(writer);
-    writer.writeAttribute(QLatin1String("drawasactor"), QString::number(m_drawAsActor));
-    writer.writeAttribute(QLatin1String("multipleinstance"), QString::number(m_multipleInstance));
-    writer.writeAttribute(QLatin1String("decon"), QString::number(m_showDestruction));
+    writer.writeAttribute(QStringLiteral("drawasactor"), QString::number(m_drawAsActor));
+    writer.writeAttribute(QStringLiteral("multipleinstance"), QString::number(m_multipleInstance));
+    writer.writeAttribute(QStringLiteral("decon"), QString::number(m_showDestruction));
     writer.writeEndElement();
 }
 
@@ -687,9 +687,9 @@ bool ObjectWidget::loadFromXMI(QDomElement& qElement)
 {
     if(!UMLWidget::loadFromXMI(qElement))
         return false;
-    QString draw = qElement.attribute(QLatin1String("drawasactor"), QLatin1String("0"));
-    QString multi = qElement.attribute(QLatin1String("multipleinstance"), QLatin1String("0"));
-    QString decon = qElement.attribute(QLatin1String("decon"), QLatin1String("0"));
+    QString draw = qElement.attribute(QStringLiteral("drawasactor"), QStringLiteral("0"));
+    QString multi = qElement.attribute(QStringLiteral("multipleinstance"), QStringLiteral("0"));
+    QString decon = qElement.attribute(QStringLiteral("decon"), QStringLiteral("0"));
 
     m_drawAsActor = (bool)draw.toInt();
     m_multipleInstance = (bool)multi.toInt();
